Module error

Module error 

Error types for the JSON-RPC implementation.

This module defines internal errors that can occur during JSON-RPC processing, distinct from the JSON-RPC wire format errors defined in the types module.

Enums

Error
Internal errors that can occur during JSON-RPC processing.